
/*
 *	Copyright: Torquil Gault (tag@scatha.apana.org.au), 1998+
 *
 */

package rpcs.system;

import com.sun.java.swing.*;
import com.sun.java.swing.table.*;
import java.awt.*;
import java.util.*;

import rpcs.system.*;

public class RPCSTable extends JPanel {
	JScrollPane ScrollPanel;
	JTable Table;
	JTableHeader THeader;
	RPCSTableModel TModel;
	DefaultTableColumnModel TCModel;
	TableColumn TColumn;
	Vector TVector;
	Vector vTitle;
	Vector vData;

	public RPCSTable(int x, int y) {
		super();
		Table = new JTable(x,y);
		Table.setModel(new RPCSTableModel(x,y));
		ScrollPanel = JTable.createScrollPaneForTable(Table);
		THeader = Table.getTableHeader();
		THeader.setReorderingAllowed(false);
		TModel = (RPCSTableModel) Table.getModel();
		TCModel = (DefaultTableColumnModel) Table.getColumnModel();
		setLayout(new GridLayout(1,0));
		add(ScrollPanel, "Center");

		Init();
	}

	public void Init() {
		vTitle = new Vector();
		vData = TModel.getDataVector();
	}

	public void addColumn(String hdr) {
		TModel.addColumn(hdr);
	}

	public void addColumn(int col, String hdr) {
	   int cl;

		TModel.addColumn(hdr);
		vTitle.insertElementAt(hdr, col);
		cl = TModel.getColumnCount();
		TCModel.moveColumn(cl-1, col);
	}

	public void setColumnHeader(int col, String hdr) {
		vTitle.setElementAt(hdr, col);
		TModel.setDataVector(vData, vTitle);
	}

	public void setColumnHeaders(String[] hdr) {
		for (int i=0; i<hdr.length; i++) {
			TModel.addColumn(hdr[i]);
			vTitle.addElement(hdr[i]);
		}
	}

	public void setColumnWidth(int col, int width) {
		TColumn = TCModel.getColumn(col);
		TColumn.setWidth(width);
		TColumn.setMaxWidth(width);
	}

	public void setColumnWidths(int[] width) {
		for (int i=0; i<width.length; i++) {
			TColumn = TCModel.getColumn(i);
			TColumn.setWidth(width[i]);
			TColumn.setMaxWidth(width[i]);
		}		
	}

	public void setColumnType(int col, Object obj) {
		TColumn = TCModel.getColumn(col);

		if (obj instanceof JComboBox) {
		   TColumn.setCellEditor(new DefaultCellEditor((JComboBox )obj));
		}
		else if (obj instanceof Number || obj instanceof Integer) {
		   TColumn.setCellRenderer(new DefaultTableCellRenderer() {
			public void setValue(Object val) {
				int cvalue = Integer.parseInt((String )val);
				setForeground((cvalue >= 0)?Color.black:Color.red);
				setText((val == null)?"0":val.toString());
			}
		   });
		}
	}

	public void addRowAt(int row, Object[] obj) {
		TModel.insertRow(row, obj);
	}

	public void addRow(Object[] obj) {
		TModel.addRow(obj);
	}

	public void addRow(Object[][] obj) {
		for (int i=0; i<obj.length; i++)
			TModel.addRow(obj[i]);
	}

	public void CleanUp() {		// removes empty rows etc
	}

	public void setValueAt(Object obj, int rw, int cl) {
		Table.setValueAt(obj, rw, cl);
	}

	public Object getValueAt(int rw, int cl) {
		return Table.getValueAt(rw, cl);
	}

	public void setEditable(int col, boolean val) {
		TModel.setEditable(col, val);
	}
}
